import java.util.HashMap;
import java.util.Iterator;

public class Robot 
        extends PackageHolder {
    
    private int m_id;
    private int m_capacity;
    private int m_drops;
    
    private int[] m_nodeWeightAdjustments;
    
    public Robot(int id, int x, int y, int capacity, int[] initialNodeWeightAdjustments) {
        super(x,y);
        m_id=id;
        m_capacity=capacity;
        m_drops=0;        // num of packages dropped
        m_nodeWeightAdjustments=initialNodeWeightAdjustments;
    }
    
    public void setNodeWeightAdjustments(int[] adj) {
        m_nodeWeightAdjustments=adj;
    }
    
    public int[] getNodeWeightAdjustments() {
        return m_nodeWeightAdjustments;
    }
    
    public int getId() {
        return m_id;
    }
    
    // pass -1 for unknown dests or weight
    public void didPick(int packageId, int destX, int destY, int weight) {
        putPackage(packageId, destX, destY, weight);
    }
    
    public void didDrop(int packageId) {
        removePackage(packageId);
        m_drops++;
    }
    
    public void didMove(int dir) {
        if (dir==Simulator.NORTH) // north means "down" cuz 1,1 is southwest
            setY(getY()+1);
        else if (dir==Simulator.SOUTH)
            setY(getY()-1);
        else if (dir==Simulator.EAST)
            setX(getX()+1);
        else if (dir==Simulator.WEST)
            setX(getX()-1);
    }
    
    public int getCapacity() {
        return m_capacity;
    }
    
    public int getDrops() {
        return m_drops;
    }
    
    public String getStats() {
        StringBuffer d=new StringBuffer();
        d.append(m_id+",x"+getX()+",y"+getY()+",c"+m_capacity+",d"+m_drops
                +",k"+getKnownPackageWeight()+",h");
        int[] hids=getPackageIds();
        d.append(hids.length);
        int id, wt;
        for (int x=0; x<hids.length; x++) {
            id=hids[x];
            wt=getPackageWeight(id);
            d.append(" #" + id + ":" + wt);
        }
        d.append(",a");
        int[] adj=getNodeWeightAdjustments();
        for (int x=0; x<adj.length; x++) {
            if (x>0) d.append(' ');
            d.append(adj[x]);
        }
        return d.toString();
    }
    
    public static void main(String[] args) {
        Robot r=new Robot(123,5,5,1000,new int[] {3,2,1});
        System.out.println(r.getStats());
        r.didPick(45, -1, 1, 1);
        System.out.println(r.getStats());
        r.didPick(48, 200, 1, 1);
        System.out.println(r.getStats());
        r.didDrop(48);
        System.out.println(r.getStats());
        r.didMove(Simulator.NORTH);
        System.out.println(r.getStats());
    }
    
}